import React, { useState } from 'react';
import genomicOverviewStyles from 'pages/patientView/genomicOverview/styles.module.scss';

// Typdefinition für einen Patienten
type Patient = {
  similarityScore: number;
  sampleID: string;
  mutations: string[];
  firstName: string;
  lastName: string;
  gender: 'm' | 'w';
  age: number;
  therapyRecommendation: 'Not realized' | 'Realized' | 'Unknown';
  therapyResponse: 'Stable disease' | 'Partial remission' | 'Unknown' | 'Progressive disease' | 'Complete remission';
  survivalStatus: 'Deceased' | 'Living';
  overallSurvivalTime: number;
  cancerType: string;
};

// Beispielhafte Patientenliste
const patients: Patient[] = [
    {
      similarityScore: 0.64,
      sampleID: 'S12345',
      mutations: ['PIK3CA', 'PTEN', 'TP53'],
      firstName: 'John',
      lastName: 'Doe',
      gender: 'm',
      age: 45,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Stable disease',
      survivalStatus: 'Living',
      overallSurvivalTime: 24,
      cancerType: 'Hepatocellular Carcinoma',
    },
    {
      similarityScore: 0.98,
      sampleID: 'S12346',
      mutations: ['KMT2D', 'PTPRT', 'PMS1'],
      firstName: 'Jane',
      lastName: 'Smith',
      gender: 'w',
      age: 50,
      therapyRecommendation: 'Not realized',
      therapyResponse: 'Partial remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 36,
      cancerType: 'Hepatocellular Carcinoma',
    },
    {
      similarityScore: 0.56,
      sampleID: 'S12347',
      mutations: ['MDC1', 'ROS1', 'FGFR1'],
      firstName: 'Alice',
      lastName: 'Johnson',
      gender: 'w',
      age: 60,
      therapyRecommendation: 'Unknown',
      therapyResponse: 'Complete remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 48,
      cancerType: 'Hepatocellular Carcinoma',
    },
    {
      similarityScore: 0.65,
      sampleID: 'S12348',
      mutations: ['RET', 'PIK3CA', 'PTEN'],
      firstName: 'Bob',
      lastName: 'Brown',
      gender: 'm',
      age: 70,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Progressive disease',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 12,
      cancerType: 'Hepatocellular Carcinoma',
    },
    {
      similarityScore: 0.99,
      sampleID: 'S12349',
      mutations: ['TP53', 'KMT2D', 'PTPRT'],
      firstName: 'Charlie',
      lastName: 'Davis',
      gender: 'm',
      age: 55,
      therapyRecommendation: 'Not realized',
      therapyResponse: 'Unknown',
      survivalStatus: 'Living',
      overallSurvivalTime: 30,
      cancerType: 'Hepatocellular Carcinoma',
    },
    {
      similarityScore: 0.93,
      sampleID: 'S12350',
      mutations: ['PMS1', 'MDC1', 'ROS1'],
      firstName: 'David',
      lastName: 'Martinez',
      gender: 'm',
      age: 65,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Stable disease',
      survivalStatus: 'Living',
      overallSurvivalTime: 40,
      cancerType: 'Acute Lymphoid Leukemia',
    },
    {
      similarityScore: 0.72,
      sampleID: 'S12351',
      mutations: ['FGFR1', 'RET', 'PIK3CA'],
      firstName: 'Eva',
      lastName: 'Garcia',
      gender: 'w',
      age: 48,
      therapyRecommendation: 'Unknown',
      therapyResponse: 'Partial remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 20,
      cancerType: 'Acute Lymphoid Leukemia',
    },
    {
      similarityScore: 0.97,
      sampleID: 'S12352',
      mutations: ['PTEN', 'TP53', 'KMT2D'],
      firstName: 'Fiona',
      lastName: 'Wilson',
      gender: 'w',
      age: 52,
      therapyRecommendation: 'Not realized',
      therapyResponse: 'Complete remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 35,
      cancerType: 'Acute Lymphoid Leukemia',
    },
    {
      similarityScore: 0.43,
      sampleID: 'S12353',
      mutations: ['PTPRT', 'PMS1', 'MDC1'],
      firstName: 'George',
      lastName: 'Anderson',
      gender: 'm',
      age: 62,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Progressive disease',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 15,
      cancerType: 'Acute Lymphoid Leukemia',
    },
    {
      similarityScore: 0.83,
      sampleID: 'S12354',
      mutations: ['ROS1', 'FGFR1', 'RET'],
      firstName: 'Helen',
      lastName: 'Thomas',
      gender: 'w',
      age: 58,
      therapyRecommendation: 'Unknown',
      therapyResponse: 'Stable disease',
      survivalStatus: 'Living',
      overallSurvivalTime: 25,
      cancerType: 'Acute Lymphoid Leukemia',
    },
    {
      similarityScore: 0.78,
      sampleID: 'S12355',
      mutations: ['PIK3CA', 'PTEN', 'TP53'],
      firstName: 'Ian',
      lastName: 'Taylor',
      gender: 'm',
      age: 49,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Complete remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 42,
      cancerType: 'Acute Lymphoid Leukemia',
    },
    {
      similarityScore: 0.57,
      sampleID: 'S12356',
      mutations: ['KMT2D', 'PTPRT', 'PMS1'],
      firstName: 'Jane',
      lastName: 'White',
      gender: 'w',
      age: 53,
      therapyRecommendation: 'Not realized',
      therapyResponse: 'Partial remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 28,
      cancerType: 'Acute Lymphoid Leukemia',
    },
    {
      similarityScore: 0.66,
      sampleID: 'S12357',
      mutations: ['MDC1', 'ROS1', 'FGFR1'],
      firstName: 'Karl',
      lastName: 'Harris',
      gender: 'm',
      age: 61,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Unknown',
      survivalStatus: 'Living',
      overallSurvivalTime: 18,
      cancerType: 'Acute Lymphoid Leukemia',
    },
    {
      similarityScore: 0.95,
      sampleID: 'S12358',
      mutations: ['RET', 'PIK3CA', 'PTEN'],
      firstName: 'Lena',
      lastName: 'Clark',
      gender: 'w',
      age: 47,
      therapyRecommendation: 'Unknown',
      therapyResponse: 'Stable disease',
      survivalStatus: 'Living',
      overallSurvivalTime: 33,
      cancerType: 'Acute Lymphoid Leukemia',
    },
    {
      similarityScore: 0.87,
      sampleID: 'S12359',
      mutations: ['TP53', 'KMT2D', 'PTPRT'],
      firstName: 'Mike',
      lastName: 'Lewis',
      gender: 'm',
      age: 50,
      therapyRecommendation: 'Not realized',
      therapyResponse: 'Progressive disease',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 10,
      cancerType: 'Acute Lymphoid Leukemia',
    },
    {
      similarityScore: 0.59,
      sampleID: 'S12360',
      mutations: ['PMS1', 'MDC1', 'ROS1'],
      firstName: 'Nina',
      lastName: 'Robinson',
      gender: 'w',
      age: 64,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Partial remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 29,
      cancerType: 'Acute Lymphoid Leukemia',
    },
    {
      similarityScore: 0.87,
      sampleID: 'S12361',
      mutations: ['FGFR1', 'RET', 'PIK3CA'],
      firstName: 'Oscar',
      lastName: 'Walker',
      gender: 'm',
      age: 55,
      therapyRecommendation: 'Unknown',
      therapyResponse: 'Complete remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 26,
      cancerType: 'Acute Lymphoid Leukemia',
    },
    {
      similarityScore: 0.81,
      sampleID: 'S12362',
      mutations: ['PTEN', 'TP53', 'KMT2D'],
      firstName: 'Paula',
      lastName: 'Young',
      gender: 'w',
      age: 70,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Stable disease',
      survivalStatus: 'Living',
      overallSurvivalTime: 22,
      cancerType: 'Acute Lymphoid Leukemia',
    },
    {
      similarityScore: 0.90,
      sampleID: 'S12363',
      mutations: ['PTPRT', 'PMS1', 'MDC1'],
      firstName: 'Quinn',
      lastName: 'King',
      gender: 'm',
      age: 40,
      therapyRecommendation: 'Not realized',
      therapyResponse: 'Progressive disease',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 9,
      cancerType: 'Breast Invasive Ductal Carcinoma',
    },
    {
      similarityScore: 0.69,
      sampleID: 'S12364',
      mutations: ['ROS1', 'FGFR1', 'RET'],
      firstName: 'Rachel',
      lastName: 'Scott',
      gender: 'w',
      age: 58,
      therapyRecommendation: 'Unknown',
      therapyResponse: 'Complete remission',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 41,
      cancerType: 'Multiple Myeloma',
    },
    {
      similarityScore: 0.58,
      sampleID: 'S12365',
      mutations: ['PIK3CA', 'PTEN', 'TP53'],
      firstName: 'Steve',
      lastName: 'Green',
      gender: 'm',
      age: 59,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Stable disease',
      survivalStatus: 'Living',
      overallSurvivalTime: 37,
      cancerType: 'Breast Invasive Ductal Carcinoma',
    },
    {
      similarityScore: 0.87,
      sampleID: 'S12366',
      mutations: ['KMT2D', 'PTPRT', 'PMS1'],
      firstName: 'Tina',
      lastName: 'Adams',
      gender: 'w',
      age: 60,
      therapyRecommendation: 'Not realized',
      therapyResponse: 'Partial remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 34,
      cancerType: 'Stomach Adenocarcinoma',
    },
    {
      similarityScore: 0.76,
      sampleID: 'S12367',
      mutations: ['MDC1', 'ROS1', 'FGFR1'],
      firstName: 'Uma',
      lastName: 'Baker',
      gender: 'w',
      age: 61,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Complete remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 32,
      cancerType: 'Stomach Adenocarcinoma',
    },
    {
      similarityScore: 0.72,
      sampleID: 'S12368',
      mutations: ['RET', 'PIK3CA', 'PTEN'],
      firstName: 'Victor',
      lastName: 'Carter',
      gender: 'm',
      age: 62,
      therapyRecommendation: 'Unknown',
      therapyResponse: 'Progressive disease',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 14,
      cancerType: 'Stomach Adenocarcinoma',
    },
    {
      similarityScore: 0.85,
      sampleID: 'S12369',
      mutations: ['TP53', 'KMT2D', 'PTPRT'],
      firstName: 'Wendy',
      lastName: 'Evans',
      gender: 'w',
      age: 63,
      therapyRecommendation: 'Not realized',
      therapyResponse: 'Stable disease',
      survivalStatus: 'Living',
      overallSurvivalTime: 27,
      cancerType: 'Uterine Endometrioid Carcinoma',
    },
    {
      similarityScore: 0.93,
      sampleID: 'S12370',
      mutations: ['PMS1', 'MDC1', 'ROS1'],
      firstName: 'Xander',
      lastName: 'Flores',
      gender: 'm',
      age: 64,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Complete remission',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 43,
      cancerType: 'Uterine Endometrioid Carcinoma',
    },
    {
      similarityScore: 0.82,
      sampleID: 'S12371',
      mutations: ['FGFR1', 'RET', 'PIK3CA'],
      firstName: 'Yvonne',
      lastName: 'Gonzalez',
      gender: 'w',
      age: 65,
      therapyRecommendation: 'Unknown',
      therapyResponse: 'Progressive disease',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 17,
      cancerType: 'Uterine Endometrioid Carcinoma',
    },
    {
      similarityScore: 0.51,
      sampleID: 'S12372',
      mutations: ['PTEN', 'TP53', 'KMT2D'],
      firstName: 'Zach',
      lastName: 'Hall',
      gender: 'm',
      age: 66,
      therapyRecommendation: 'Not realized',
      therapyResponse: 'Stable disease',
      survivalStatus: 'Living',
      overallSurvivalTime: 39,
      cancerType: 'Choriocarcinoma',
    },
    {
      similarityScore: 0.79,
      sampleID: 'S12373',
      mutations: ['PTPRT', 'PMS1', 'MDC1'],
      firstName: 'Adam',
      lastName: 'Hernandez',
      gender: 'm',
      age: 67,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Partial remission',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 21,
      cancerType: '	Choriocarcinoma',
    },
    {
      similarityScore: 0.69,
      sampleID: 'S12374',
      mutations: ['ROS1', 'FGFR1', 'RET'],
      firstName: 'Beth',
      lastName: 'Jackson',
      gender: 'w',
      age: 68,
      therapyRecommendation: 'Unknown',
      therapyResponse: 'Complete remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 30,
      cancerType: 'Choriocarcinoma',
    },
    {
      similarityScore: 0.88,
      sampleID: 'S12375',
      mutations: ['PIK3CA', 'PTEN', 'TP53'],
      firstName: 'Carl',
      lastName: 'Lee',
      gender: 'm',
      age: 69,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Stable disease',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 35,
      cancerType: 'Merkel Cell Carcinoma	',
    },
    {
      similarityScore: 0.77,
      sampleID: 'S12376',
      mutations: ['KMT2D', 'PTPRT', 'PMS1'],
      firstName: 'Dana',
      lastName: 'Mitchell',
      gender: 'w',
      age: 70,
      therapyRecommendation: 'Not realized',
      therapyResponse: 'Progressive disease',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 16,
      cancerType: 'Intrahepatic Cholangiocarcinoma',
    },
    {
      similarityScore: 0.66,
      sampleID: 'S12377',
      mutations: ['MDC1', 'ROS1', 'FGFR1'],
      firstName: 'Eric',
      lastName: 'Nelson',
      gender: 'm',
      age: 71,
      therapyRecommendation: 'Unknown',
      therapyResponse: 'Complete remission',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 50,
      cancerType: 'Intrahepatic Cholangiocarcinoma',
    },
    {
      similarityScore: 0.55,
      sampleID: 'S12378',
      mutations: ['RET', 'PIK3CA', 'PTEN'],
      firstName: 'Faith',
      lastName: 'Perez',
      gender: 'w',
      age: 72,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Stable disease',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 20,
      cancerType: 'Intrahepatic Cholangiocarcinoma',
    },
    {
      similarityScore: 0.94,
      sampleID: 'S12379',
      mutations: ['TP53', 'KMT2D', 'PTPRT'],
      firstName: 'Gary',
      lastName: 'Roberts',
      gender: 'm',
      age: 73,
      therapyRecommendation: 'Not realized',
      therapyResponse: 'Partial remission',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 25,
      cancerType: 'Small Cell Lung Cancer',
    },
    {
      similarityScore: 0.98,
      sampleID: 'S12380',
      mutations: ['PMS1', 'MDC1', 'ROS1'],
      firstName: 'Hannah',
      lastName: 'Sanders',
      gender: 'w',
      age: 74,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Complete remission',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 38,
      cancerType: 'Non Small Cell Lung Cancer',
    },
    {
      similarityScore: 0.92,
      sampleID: 'S12381',
      mutations: ['FGFR1', 'RET', 'PIK3CA'],
      firstName: 'Isaac',
      lastName: 'Thompson',
      gender: 'm',
      age: 75,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Stable disease',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 29,
      cancerType: 'Small Cell Lung Cancer',
    },
    {
      similarityScore: 0.68,
      sampleID: 'S12382',
      mutations: ['PTEN', 'TP53', 'KMT2D'],
      firstName: 'Jackie',
      lastName: 'Turner',
      gender: 'w',
      age: 76,
      therapyRecommendation: 'Not realized',
      therapyResponse: 'Partial remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 40,
      cancerType: 'Papillary Thyroid Cancer',
    },
    {
      similarityScore: 0.69,
      sampleID: 'S12383',
      mutations: ['PTPRT', 'PMS1', 'MDC1'],
      firstName: 'Kevin',
      lastName: 'Wright',
      gender: 'm',
      age: 77,
      therapyRecommendation: 'Unknown',
      therapyResponse: 'Complete remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 45,
      cancerType: 'High-Grade Serous Ovarian Cancer',
    },
    {
      similarityScore: 0.51,
      sampleID: 'S12384',
      mutations: ['ROS1', 'FGFR1', 'RET'],
      firstName: 'Linda',
      lastName: 'Young',
      gender: 'w',
      age: 78,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Stable disease',
      survivalStatus: 'Living',
      overallSurvivalTime: 44,
      cancerType: 'High-Grade Serous Ovarian Cancer',
    },
    {
      similarityScore: 0.61,
      sampleID: 'S12385',
      mutations: ['PIK3CA', 'PTEN', 'TP53'],
      firstName: 'Mike',
      lastName: 'Zimmerman',
      gender: 'm',
      age: 79,
      therapyRecommendation: 'Not realized',
      therapyResponse: 'Progressive disease',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 13,
      cancerType: 'High-Grade Serous Ovarian Cancer',
    },
    {
      similarityScore: 0.47,
      sampleID: 'S12386',
      mutations: ['KMT2D', 'PTPRT', 'PMS1'],
      firstName: 'Nina',
      lastName: 'Stewart',
      gender: 'w',
      age: 80,
      therapyRecommendation: 'Unknown',
      therapyResponse: 'Partial remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 31,
      cancerType: 'Prostate Adenocarcinoma',
    },
    {
      similarityScore: 0.66,
      sampleID: 'S12387',
      mutations: ['MDC1', 'ROS1', 'FGFR1'],
      firstName: 'Oliver',
      lastName: 'Watson',
      gender: 'm',
      age: 81,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Complete remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 50,
      cancerType: 'Prostate Adenocarcinoma',
    },
    {
      similarityScore: 0.55,
      sampleID: 'S12388',
      mutations: ['RET', 'PIK3CA', 'PTEN'],
      firstName: 'Pamela',
      lastName: 'Hall',
      gender: 'w',
      age: 82,
      therapyRecommendation: 'Not realized',
      therapyResponse: 'Progressive disease',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 12,
      cancerType: 'Prostate Adenocarcinoma',
    },
    {
      similarityScore: 0.95,
      sampleID: 'S12389',
      mutations: ['TP53', 'KMT2D', 'PTPRT'],
      firstName: 'Quentin',
      lastName: 'Hill',
      gender: 'm',
      age: 83,
      therapyRecommendation: 'Unknown',
      therapyResponse: 'Stable disease',
      survivalStatus: 'Living',
      overallSurvivalTime: 46,
      cancerType: 'Uterine Leiomyosarcoma',
    },
    {
      similarityScore: 0.94,
      sampleID: 'S12390',
      mutations: ['PMS1', 'MDC1', 'ROS1'],
      firstName: 'Rachel',
      lastName: 'Patterson',
      gender: 'w',
      age: 84,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Partial remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 23,
      cancerType: 'Uterine Leiomyosarcoma',
    },
    {
      similarityScore: 0.82,
      sampleID: 'S12391',
      mutations: ['FGFR1', 'RET', 'PIK3CA'],
      firstName: 'Sam',
      lastName: 'Cruz',
      gender: 'm',
      age: 85,
      therapyRecommendation: 'Not realized',
      therapyResponse: 'Complete remission',
      survivalStatus: 'Living',
      overallSurvivalTime: 19,
      cancerType: 'Uterine Leiomyosarcoma',
    },
    {
      similarityScore: 0.61,
      sampleID: 'S12392',
      mutations: ['PTEN', 'TP53', 'KMT2D'],
      firstName: 'Tina',
      lastName: 'Morris',
      gender: 'w',
      age: 86,
      therapyRecommendation: 'Unknown',
      therapyResponse: 'Progressive disease',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 18,
      cancerType: '	Medullary Thyroid Cancer',
    },
    {
      similarityScore: 0.70,
      sampleID: 'S12393',
      mutations: ['PTPRT', 'PMS1', 'MDC1'],
      firstName: 'Ursula',
      lastName: 'Perez',
      gender: 'w',
      age: 87,
      therapyRecommendation: 'Realized',
      therapyResponse: 'Stable disease',
      survivalStatus: 'Deceased',
      overallSurvivalTime: 47,
      cancerType: '	Medullary Thyroid Cancer',
    },
  ];
  

  const OverviewTable: React.FC = () => {
    // Patienten nach Similarity Score absteigend sortieren
    const sortedPatients = [...patients].sort((a, b) => b.similarityScore - a.similarityScore);
  
    // State für die Paginierung
    const [currentPage, setCurrentPage] = useState(1);
    const [entriesPerPage, setEntriesPerPage] = useState(10);
  
    // Berechne den Index des ersten und letzten Patienten auf der aktuellen Seite
    const indexOfLastPatient = currentPage * entriesPerPage;
    const indexOfFirstPatient = indexOfLastPatient - entriesPerPage;
    const currentPatients = sortedPatients.slice(indexOfFirstPatient, indexOfLastPatient);
  
    // Gesamtzahl der Seiten berechnen
    const totalPages = Math.ceil(sortedPatients.length / entriesPerPage);
  
    // Funktion zum Wechseln der Seite
    const handlePageChange = (pageNumber: number) => {
      setCurrentPage(pageNumber);
    };
  
    // Funktion zum Ändern der Anzahl der Einträge pro Seite
    const handleEntriesChange = (event: React.ChangeEvent<HTMLSelectElement>) => {
      setEntriesPerPage(parseInt(event.target.value));
      setCurrentPage(1); // Setzt die Seite zurück auf 1 bei Änderung der Anzahl der Einträge
    };
  
    return (
      <div>
        <div className="pagination-controls">
          <label>
            Entries per page:
            <select value={entriesPerPage} onChange={handleEntriesChange}>
              <option value={5}>5</option>
              <option value={10}>10</option>
              <option value={20}>20</option>
              <option value={50}>50</option>
            </select>
          </label>
        </div>
  
        <table className='simple-table table table-striped table-border-top'>
          <thead>
            <tr>
              <th>Similarity Score</th>
              <th>Sample ID</th>
              <th>Mutations</th>
              <th>Patient</th>
              <th>Therapy Recommendation</th>
              <th>Therapy Response</th>
              <th>Overall Survival Status</th>
              <th>Overall Survival (Months)</th>
              <th>Cancer Type</th>
            </tr>
          </thead>
          <tbody>
            {currentPatients.map((patient, index) => (
              <tr key={index} style={{ backgroundColor: index % 2 === 0 ? '#f9f9f9' : '#ffffff' }}>
                <td>{patient.similarityScore.toFixed(2)}</td>
                <td>{patient.sampleID}</td>
                <td>{patient.mutations.join(', ')}</td>
                <td>{patient.firstName} {patient.lastName} ({patient.gender}/{patient.age})</td>
                <td>{patient.therapyRecommendation}</td>
                <td>{patient.therapyResponse}</td>
                <td>{patient.survivalStatus}</td>
                <td>{patient.overallSurvivalTime}</td>
                <td>{patient.cancerType}</td>
              </tr>
            ))}
          </tbody>
        </table>
  
        <div className="pagination-controls">
          <button 
            onClick={() => handlePageChange(currentPage - 1)} 
            disabled={currentPage === 1}
          >
            Previous
          </button>
          <span>Page {currentPage} of {totalPages}</span>
          <button 
            onClick={() => handlePageChange(currentPage + 1)} 
            disabled={currentPage === totalPages}
          >
            Next
          </button>
        </div>
      </div>
    );
  };
  
  export default OverviewTable;
