import { MSKTab, MSKTabs } from 'shared/components/MSKTabs/MSKTabs';
import LoadingIndicator from 'shared/components/loadingIndicator/LoadingIndicator';
import TimelineWrapper from 'pages/patientView/timeline/TimelineWrapper';
import WindowStore from 'shared/components/window/WindowStore';
import GenomicOverview from 'pages/patientView/genomicOverview/GenomicOverview';
import { defaultAlleleFrequencyHeaderTooltip } from 'pages/patientView/mutation/PatientViewMutationTable';
import { getServerConfig, ServerConfigHelpers } from 'config/config';
import StructuralVariantTableWrapper from 'pages/patientView/structuralVariant/StructuralVariantTableWrapper';
import CopyNumberTableWrapper from 'pages/patientView/copyNumberAlterations/CopyNumberTableWrapper';
import PatientViewMutationsTab from 'pages/patientView/mutation/PatientViewMutationsTab';
import PatientViewPathwayMapper from 'pages/patientView/pathwayMapper/PatientViewPathwayMapper';
import ClinicalInformationPatientTable from 'pages/patientView/clinicalInformation/ClinicalInformationPatientTable';
import ClinicalInformationSamples from 'pages/patientView/clinicalInformation/ClinicalInformationSamplesTable';
import ClinicalEventsTables from 'pages/patientView/timeline/ClinicalEventsTables';
import ResourcesTab, {
    RESOURCES_TAB_NAME,
} from 'pages/patientView/resources/ResourcesTab';
import PathologyReport from 'pages/patientView/pathologyReport/PathologyReport';
import IFrameLoader from 'shared/components/iframeLoader/IFrameLoader';
import { getDigitalSlideArchiveIFrameUrl, getPatientViewUrl } from 'shared/api/urls';
import TrialMatchTable from 'pages/patientView/trialMatch/TrialMatchTable';
import _ from 'lodash';
import MutationalSignaturesContainer from 'pages/patientView/mutationalSignatures/MutationalSignaturesContainer';
import { buildCustomTabs } from 'shared/lib/customTabs/customTabHelpers';
import * as React from 'react';
import SampleManager from 'pages/patientView/SampleManager';
import PatientViewPage from 'pages/patientView/PatientViewPage';
import PatientViewUrlWrapper from 'pages/patientView/PatientViewUrlWrapper';
import { ClinicalTrialMatchTable } from './clinicalTrialMatch/ClinicalTrialMatchTable';
import MtbTable from './therapyRecommendation/MtbTable';
import { CompactVAFPlot } from 'pages/patientView/genomicOverview/CompactVAFPlot';
import {
    computeMutationFrequencyBySample,
    doesFrequencyExist,
} from 'pages/patientView/genomicOverview/GenomicOverviewUtils';
import genomicOverviewStyles from 'pages/patientView/genomicOverview/styles.module.scss';
import FeatureInstruction from 'shared/FeatureInstruction/FeatureInstruction';
import { HelpWidget } from 'shared/components/HelpWidget/HelpWidget';
import FollowUpTable from './therapyRecommendation/FollowUpTable';
import MutationTableWrapper from './mutation/MutationTableWrapper';
import { PatientViewPageInner } from 'pages/patientView/PatientViewPage';
import { Else, If } from 'react-if';

//JAN
import CBioPortalAPI from '/home/bosseja/new_frontend/cbioportal-frontend/packages/cbioportal-ts-api-client/dist/generated/CBioPortalAPI';
import { DatasetPageStore } from 'pages/staticPages/datasetView/DatasetPage';
import { StudyView } from 'config/IAppConfig';
import { StudyViewPageStore } from 'pages/studyView/StudyViewPageStore';
import { ClinicalDataTab } from 'pages/studyView/tabs/ClinicalDataTab';
import { AppStore } from 'AppStore';
import StudyViewURLWrapper from 'pages/studyView/StudyViewURLWrapper';
import ExtendedRouterStore from 'shared/lib/ExtendedRouterStore';
import { PatientViewPageStore } from './clinicalInformation/PatientViewPageStore';
import { useState, useEffect  } from 'react';
import { storeDecorator } from 'mobx/dist/internal';
import SharedMutationsTable from './Patient_comparison';
import OverviewTable from './OverviewTable';

export enum PatientViewPageTabs {
    Summary = 'summary',
    genomicEvolution = 'genomicEvolution',
    ClinicalData = 'clinicalData',
    FilesAndLinks = 'filesAndLinks',
    PathologyReport = 'pathologyReport',
    TissueImage = 'tissueImage',
    MSKTissueImage = 'MSKTissueImage',
    TrialMatchTab = 'trialMatchTab',
    MutationalSignatures = 'mutationalSignatures',
    PathwayMapper = 'pathways',
    Mtb = 'mtb',
    FollowUp = 'followUp',
    ClinicalTrialsGov = 'clinicaltrialsGov',
    PatientSimilarity = 'PatientSimilarity',
    PatientComparison = 'PatientComparison'
}
export function isNullOrUndefined(): boolean {
    return this.value === null || this.value === undefined;
}

export const PatientViewResourceTabPrefix = 'openResource_';

export function getPatientViewResourceTabId(resourceId: string) {
    return `${PatientViewResourceTabPrefix}${resourceId}`;
}

export function extractResourceIdFromTabId(tabId: string) {
    const match = new RegExp(`${PatientViewResourceTabPrefix}(.*)`).exec(tabId);
    if (match) {
        return match[1];
    } else {
        return undefined;
    }
}


export const PatientTable: React.FC<TableProps> = ({ studyViewPageStore, patientViewPageStore }) => {
    const [currentPage, setCurrentPage] = useState(0);
    const [entriesPerPage, setEntriesPerPage] = useState(5);
    const [isLoading, setIsLoading] = useState(true);

    // Erstelle PatientViewPageStores für jede sampleId
    const patientViewPageStores = studyViewPageStore.getDataForClinicalDataTab.result.map(
        element => new PatientViewPageStore (
            patientViewPageStore.appStore,
            element.studyId,
            element.patientId,
            element.sampleId
        )
    );

    useEffect(() => {
        const interval = setInterval(() => {
            const allDataLoaded = patientViewPageStores.every(store => !store.mutationData.isPending);
            if (allDataLoaded) {
                setIsLoading(false);
                clearInterval(interval);
            }
        }, 100); // Überprüfen alle 100ms
        return () => clearInterval(interval);
    }, [patientViewPageStores]);

    // Daten mit Similarity Scores bereichern, aber den Eintrag von patientViewPageStore ausschließen
    const dataWithScores = studyViewPageStore.getDataForClinicalDataTab.result
        .filter(element => element.sampleId !== patientViewPageStore.sampleId)
        .map(element => ({
            ...element,
            similarityScore: Math.floor(Math.random() * 100) + 1
        }));

    // Daten nach Similarity Scores sortieren
    const sortedData = dataWithScores.sort((a, b) => b.similarityScore - a.similarityScore);

    // Paginierte Daten berechnen
    const paginatedData = sortedData.slice(currentPage * entriesPerPage, (currentPage + 1) * entriesPerPage);

    // Funktionshandler für die Paginierung
    const handleNextPage = () => {
        if ((currentPage + 1) * entriesPerPage < sortedData.length) {
            setCurrentPage(currentPage + 1);
        }
    };

    const handlePreviousPage = () => {
        if (currentPage > 0) {
            setCurrentPage(currentPage - 1);
        }
    };

    const handleEntriesPerPageChange = (event: React.ChangeEvent<HTMLInputElement>) => {
        const newEntriesPerPage = parseInt(event.target.value, 10);
        if (!isNaN(newEntriesPerPage) && newEntriesPerPage > 0) {
            setEntriesPerPage(newEntriesPerPage);
            setCurrentPage(0); // Reset to first page when entries per page changes
        }
    };

    return (
        <div>
            <div className="entries-per-page-control">
                <label htmlFor="entries-per-page">Entries per page:</label>
                <input
                    type="number"
                    id="entries-per-page"
                    value={entriesPerPage}
                    onChange={handleEntriesPerPageChange}
                    min="1"
                />
            </div>
            
                <table className="simple-table table table-striped table-border-top">
                    <thead>
                        <tr>
                            <th>Similarity Score</th>
                            <th>Sample ID</th>
                            <th>Mutations</th>
                            <th>Geschlecht (1)</th>
                            <th>Best Response Vortherapie (5) hier sollte eigentlich die Therapyempfehlung stehen</th>
                            <th>PFS (8) </th>
                            <th>Overall Survival Status (4)</th>
                            <th>Overall Survival (Months) (3)</th>
                            <th>Cancer Type</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr key={-1}>
                            <td>aktueller Patient</td>
                            <td>{patientViewPageStore.sampleId}</td>
                            <td>{patientViewPageStore.mutationData.result[1].gene.hugoGeneSymbol +", "+ patientViewPageStore.mutationData.result[5].gene.hugoGeneSymbol +", "+ patientViewPageStore.mutationData.result[7].gene.hugoGeneSymbol }</td>
                            <td>{patientViewPageStore.clinicalDataPatient.result[1].value} </td>
                            <td>{patientViewPageStore.clinicalDataPatient.result[5].value} </td>
                            <td>{patientViewPageStore.clinicalDataPatient.result[8].value} </td>
                            <td>{patientViewPageStore.clinicalDataPatient.result[4].value} </td>
                            <td>{patientViewPageStore.clinicalDataPatient.result[3].value} </td>
                            <td>{patientViewPageStore.clinicalDataPatient.result[11].value} </td>
                        </tr>
                        {paginatedData.map((element, index) => {
                            const correspondingPatientViewPageStore = patientViewPageStores.find(
                                store => store.sampleId === element.sampleId
                            )!; 

                            return (
                                <tr key={index}>
                                    <td>{element.similarityScore}</td>
                                    <td>{element.sampleId}</td>
                                    <td>{element.sampleId}</td>
                                    <td>{element.sampleId}</td>
                                    <td>{element.sampleId}</td>
                                    <td>{element.sampleId}</td>
                                    <td>{element.sampleId}</td>
                                    <td>{element.sampleId}</td>
                                    <td>{element.sampleId}</td>
                                </tr>
                            );
                        })}
                    </tbody>
                </table>
            <div className="pagination-controls">
                <button onClick={handlePreviousPage} disabled={currentPage === 0}>
                    Previous
                </button>
                <button onClick={handleNextPage} disabled={(currentPage + 1) * entriesPerPage >= sortedData.length}>
                    Next
                </button>
            </div>
        </div>
    );
};

interface TableProps {
    studyViewPageStore: {
        getDataForClinicalDataTab: {
            result: Array<{
                sampleId: string;
                studyId: string;
                patientId: string;
                // andere Felder
            }>
        }
    };
    patientViewPageStore: PatientViewPageStore;
}


export function patientViewTabs(
    pageInstance: PatientViewPageInner,
    urlWrapper: PatientViewUrlWrapper,
    sampleManager: SampleManager | null
) {
    return (
        <MSKTabs
            id="patientViewPageTabs"
            key={urlWrapper.hash}
            activeTabId={urlWrapper.activeTabId}
            onTabClick={(id: string) => urlWrapper.setActiveTab(id)}
            className="mainTabs"
            getPaginationWidth={WindowStore.getWindowWidth}
            onMount={() => console.log('TABS MOUNT')}
            contentWindowExtra={
                <HelpWidget path={urlWrapper.routing.location.pathname} />
            }
        >
            {tabs(pageInstance, sampleManager)}
        </MSKTabs>
    );
}

export function tabs(
    pageComponent: PatientViewPageInner,
    sampleManager: SampleManager | null
    
) {
    const tabs: JSX.Element[] = [];
    tabs.push(
        <MSKTab key={0} id={PatientViewPageTabs.Summary} linkText="Summary">
            <LoadingIndicator
                isLoading={
                    pageComponent.patientViewPageStore.clinicalEvents.isPending
                }
            />

            {!!sampleManager &&
                pageComponent.patientViewPageStore.clinicalEvents.isComplete &&
                pageComponent.patientViewPageStore.clinicalEvents.result
                    .length > 0 && (
                    <div>
                        <div
                            style={{
                                marginTop: 20,
                                marginBottom: 20,
                            }}
                        >
                            <TimelineWrapper
                                dataStore={
                                    pageComponent.patientViewMutationDataStore
                                }
                                caseMetaData={{
                                    color: sampleManager.sampleColors,
                                    label: sampleManager.sampleLabels,
                                    index: sampleManager.sampleIndex,
                                }}
                                data={
                                    pageComponent.patientViewPageStore
                                        .clinicalEvents.result
                                }
                                sampleManager={sampleManager}
                                width={WindowStore.size.width}
                                samples={
                                    pageComponent.patientViewPageStore.samples
                                        .result
                                }
                                mutationProfileId={
                                    pageComponent.patientViewPageStore
                                        .mutationMolecularProfileId.result!
                                }
                            />
                        </div>
                        <hr />
                    </div>
                )}

            <LoadingIndicator
                isLoading={
                    pageComponent.patientViewPageStore.mutationData.isPending ||
                    pageComponent.patientViewPageStore.cnaSegments.isPending ||
                    pageComponent.patientViewPageStore.sequencedSampleIdsInStudy
                        .isPending ||
                    pageComponent.patientViewPageStore
                        .sampleToMutationGenePanelId.isPending ||
                    pageComponent.patientViewPageStore
                        .sampleToDiscreteGenePanelId.isPending ||
                    pageComponent.patientViewPageStore.studies.isPending
                }
            />

            {pageComponent.patientViewPageStore.mutationData.isComplete &&
                pageComponent.patientViewPageStore.cnaSegments.isComplete &&
                pageComponent.patientViewPageStore.sequencedSampleIdsInStudy
                    .isComplete &&
                pageComponent.patientViewPageStore.sampleToMutationGenePanelId
                    .isComplete &&
                pageComponent.patientViewPageStore.sampleToDiscreteGenePanelId
                    .isComplete &&
                pageComponent.patientViewPageStore.studies.isComplete &&
                (pageComponent.patientViewPageStore
                    .mergedMutationDataFilteredByGene.length > 0 ||
                    pageComponent.patientViewPageStore.cnaSegments.result
                        .length > 0) &&
                sampleManager && (
                    <FeatureInstruction
                        content={
                            'Click alteration for detail. Double-click to zoom.'
                        }
                        style={{ top: -10 }}
                    >
                        <GenomicOverview
                            store={pageComponent.patientViewPageStore}
                            onResetView={pageComponent.onResetViewClick}
                            mergedMutations={
                                pageComponent.patientViewPageStore
                                    .mergedMutationDataFilteredByGene
                            }
                            samples={
                                pageComponent.patientViewPageStore.samples
                                    .result
                            }
                            cnaSegments={
                                pageComponent.patientViewPageStore.cnaSegments
                                    .result
                            }
                            sampleOrder={sampleManager.sampleIndex}
                            sampleLabels={sampleManager.sampleLabels}
                            sampleColors={sampleManager.sampleColors}
                            sampleManager={sampleManager}
                            containerWidth={WindowStore.size.width - 20}
                            sampleIdToMutationGenePanelId={
                                pageComponent.patientViewPageStore
                                    .sampleToMutationGenePanelId.result
                            }
                            sampleIdToCopyNumberGenePanelId={
                                pageComponent.patientViewPageStore
                                    .sampleToDiscreteGenePanelId.result
                            }
                            onSelectGenePanel={
                                pageComponent.toggleGenePanelModal
                            }
                            disableTooltip={pageComponent.genePanelModal.isOpen}
                            // assuming that all studies have the same reference genome
                            genome={
                                pageComponent.patientViewPageStore.studies
                                    .result[0]?.referenceGenome
                            }
                        />
                        <hr />
                    </FeatureInstruction>
                )}

            <LoadingIndicator
                isLoading={
                    pageComponent.patientViewPageStore.mutationData.isPending ||
                    pageComponent.patientViewPageStore.uncalledMutationData
                        .isPending ||
                    pageComponent.patientViewPageStore.oncoKbAnnotatedGenes
                        .isPending ||
                    pageComponent.patientViewPageStore.studyIdToStudy.isPending
                }
            />

            <div data-test="patientview-mutation-table">
                <MutationTableWrapper
                    patientViewPageStore={pageComponent.patientViewPageStore}
                    dataStore={pageComponent.patientViewMutationDataStore}
                    sampleManager={sampleManager}
                    sampleIds={
                        sampleManager
                            ? sampleManager.getActiveSampleIdsInOrder()
                            : []
                    }
                    mergeOncoKbIcons={
                        pageComponent.mergeMutationTableOncoKbIcons
                    }
                    onOncoKbIconToggle={pageComponent.handleOncoKbIconToggle}
                    columnVisibility={
                        pageComponent.mutationTableColumnVisibility
                    }
                    onFilterGenes={pageComponent.onFilterGenesMutationTable}
                    columnVisibilityProps={{
                        onColumnToggled:
                            pageComponent.onMutationTableColumnVisibilityToggled,
                    }}
                    onSelectGenePanel={pageComponent.toggleGenePanelModal}
                    disableTooltip={pageComponent.genePanelModal.isOpen}
                    onRowClick={pageComponent.onMutationTableRowClick}
                    onRowMouseEnter={pageComponent.onMutationTableRowMouseEnter}
                    onRowMouseLeave={pageComponent.onMutationTableRowMouseLeave}
                    namespaceColumns={
                        pageComponent.patientViewMutationDataStore
                            .namespaceColumnConfig
                    }
                    columns={pageComponent.columns}
                    pageMode={pageComponent.patientViewPageStore.pageMode}
                    alleleFreqHeaderRender={
                        pageComponent.patientViewPageStore
                            .mergedMutationDataFilteredByGene.length > 0 &&
                        doesFrequencyExist(
                            computeMutationFrequencyBySample(
                                pageComponent.patientViewPageStore
                                    .mergedMutationDataFilteredByGene,
                                sampleManager?.sampleIndex || {}
                            )
                        )
                            ? (name: string) => (
                                  <CompactVAFPlot
                                      mergedMutations={
                                          pageComponent.patientViewPageStore
                                              .mergedMutationDataFilteredByGene
                                      }
                                      sampleManager={
                                          pageComponent.patientViewPageStore
                                              .sampleManager.result
                                      }
                                      sampleIdToMutationGenePanelId={
                                          pageComponent.patientViewPageStore
                                              .sampleToMutationGenePanelId
                                              .result
                                      }
                                      sampleIdToCopyNumberGenePanelId={
                                          pageComponent.patientViewPageStore
                                              .sampleToDiscreteGenePanelId
                                              .result
                                      }
                                      tooltip={
                                          <div>
                                              {
                                                  defaultAlleleFrequencyHeaderTooltip
                                              }
                                          </div>
                                      }
                                      thumbnailComponent={
                                          <span
                                              style={{
                                                  display: 'inline-flex',
                                              }}
                                          >
                                              <span>{name}</span>
                                              <span
                                                  className={
                                                      genomicOverviewStyles.compactVafPlot
                                                  }
                                              >
                                                  {
                                                      CompactVAFPlot
                                                          .defaultProps
                                                          .thumbnailComponent
                                                  }
                                              </span>
                                          </span>
                                      }
                                  />
                              )
                            : undefined
                    }
                />
            </div>

            <hr />

            <StructuralVariantTableWrapper
                store={pageComponent.patientViewPageStore}
                onSelectGenePanel={pageComponent.toggleGenePanelModal}
                mergeOncoKbIcons={pageComponent.mergeMutationTableOncoKbIcons}
                onOncoKbIconToggle={pageComponent.handleOncoKbIconToggle}
                enableOncoKb={getServerConfig().show_oncokb}
                sampleIds={
                    sampleManager
                        ? sampleManager.getActiveSampleIdsInOrder()
                        : []
                }
                namespaceColumns={
                    pageComponent.patientViewPageStore.namespaceColumnConfig
                        .structVar
                }
                customDriverName={
                    getServerConfig()
                        .oncoprint_custom_driver_annotation_binary_menu_label!
                }
                customDriverDescription={
                    getServerConfig()
                        .oncoprint_custom_driver_annotation_binary_menu_description!
                }
                customDriverTiersName={
                    getServerConfig()
                        .oncoprint_custom_driver_annotation_tiers_menu_label!
                }
                customDriverTiersDescription={
                    getServerConfig()
                        .oncoprint_custom_driver_annotation_tiers_menu_description!
                }
            />

            <hr />

            {pageComponent.patientViewPageStore.studyIdToStudy.isComplete &&
                pageComponent.patientViewPageStore.genePanelIdToEntrezGeneIds
                    .isComplete &&
                pageComponent.patientViewPageStore.referenceGenes.isComplete &&
                pageComponent.patientViewPageStore.discreteMolecularProfile
                    .isComplete &&
                pageComponent.patientViewPageStore
                    .genePanelDataByMolecularProfileIdAndSampleId
                    .isComplete && (
                    <div data-test="patientview-copynumber-table">
                        <If
                            condition={
                                pageComponent.patientViewPageStore
                                    .discreteMolecularProfile.result
                            }
                        >
                            <Else>
                                <div className="alert alert-info" role="alert">
                                    Study is not profiled for copy number
                                    alterations.
                                </div>
                            </Else>
                            <CopyNumberTableWrapper
                                pageStore={pageComponent.patientViewPageStore}
                                dataStore={
                                    pageComponent.patientViewCnaDataStore
                                }
                                sampleIds={
                                    sampleManager
                                        ? sampleManager.getActiveSampleIdsInOrder()
                                        : []
                                }
                                sampleManager={sampleManager}
                                enableOncoKb={getServerConfig().show_oncokb}
                                columnVisibility={
                                    pageComponent.cnaTableColumnVisibility
                                }
                                onFilterGenes={
                                    pageComponent.onFilterGenesCopyNumberTable
                                }
                                columnVisibilityProps={{
                                    onColumnToggled:
                                        pageComponent.onCnaTableColumnVisibilityToggled,
                                }}
                                onSelectGenePanel={
                                    pageComponent.toggleGenePanelModal
                                }
                                disableTooltip={
                                    pageComponent.genePanelModal.isOpen
                                }
                                mergeOncoKbIcons={
                                    pageComponent.mergeMutationTableOncoKbIcons
                                }
                                onOncoKbIconToggle={
                                    pageComponent.handleOncoKbIconToggle
                                }
                                onRowClick={pageComponent.onCnaTableRowClick}
                                namespaceColumns={
                                    pageComponent.patientViewPageStore
                                        .namespaceColumnConfig.cna
                                }
                                customDriverName={
                                    getServerConfig()
                                        .oncoprint_custom_driver_annotation_binary_menu_label!
                                }
                                customDriverDescription={
                                    getServerConfig()
                                        .oncoprint_custom_driver_annotation_binary_menu_description!
                                }
                                customDriverTiersName={
                                    getServerConfig()
                                        .oncoprint_custom_driver_annotation_tiers_menu_label!
                                }
                                customDriverTiersDescription={
                                    getServerConfig()
                                        .oncoprint_custom_driver_annotation_tiers_menu_description!
                                }
                            />
                        </If>
                    </div>
                )}
        </MSKTab>
    );

    !!sampleManager &&
        pageComponent.patientViewPageStore.sampleIds.length > 1 &&
        pageComponent.patientViewPageStore.existsSomeMutationWithVAFData &&
        tabs.push(
            <MSKTab key={1} id="genomicEvolution" linkText="Genomic Evolution">
                <PatientViewMutationsTab
                    patientViewPageStore={pageComponent.patientViewPageStore}
                    mutationTableColumnVisibility={
                        pageComponent.mutationTableColumnVisibility
                    }
                    sampleIds={pageComponent.patientViewPageStore.sampleIds}
                    onMutationTableColumnVisibilityToggled={
                        pageComponent.onMutationTableColumnVisibilityToggled
                    }
                    sampleManager={sampleManager}
                    urlWrapper={pageComponent.urlWrapper}
                    mergeOncoKbIcons={
                        pageComponent.mergeMutationTableOncoKbIcons
                    }
                    onOncoKbIconToggle={pageComponent.handleOncoKbIconToggle}
                    customDriverName={
                        getServerConfig()
                            .oncoprint_custom_driver_annotation_binary_menu_label!
                    }
                    customDriverDescription={
                        getServerConfig()
                            .oncoprint_custom_driver_annotation_binary_menu_description!
                    }
                    customDriverTiersName={
                        getServerConfig()
                            .oncoprint_custom_driver_annotation_tiers_menu_label!
                    }
                    customDriverTiersDescription={
                        getServerConfig()
                            .oncoprint_custom_driver_annotation_tiers_menu_description!
                    }
                />
            </MSKTab>
        );

    tabs.push(
        <MSKTab
            key={8}
            id={PatientViewPageTabs.PathwayMapper}
            linkText={'Pathways'}
        >
            {pageComponent.patientViewPageStore.geneticTrackData.isComplete &&
            pageComponent.patientViewPageStore
                .mergedMutationDataIncludingUncalledFilteredByGene ? (
                <PatientViewPathwayMapper
                    store={pageComponent.patientViewPageStore}
                    sampleManager={sampleManager}
                />
            ) : (
                <LoadingIndicator isLoading={true} size={'big'} center={true} />
            )}
        </MSKTab>
    );

    tabs.push(
        <MSKTab
            key={2}
            id={PatientViewPageTabs.ClinicalData}
            linkText="Clinical Data"
            className={'patient-clinical-data-tab'}
        >
            <div className="clearfix">
                <h3 className={'pull-left'}>Patient</h3>
                {pageComponent.patientViewPageStore.clinicalDataPatient
                    .isComplete && (
                    <ClinicalInformationPatientTable
                        showTitleBar={true}
                        data={
                            pageComponent.patientViewPageStore
                                .clinicalDataPatient.result
                        }
                    />
                )}
            </div>

            <div className="clearfix">
                <h3 className={'pull-left'}>Samples</h3>
                {pageComponent.patientViewPageStore.clinicalDataGroupedBySample
                    .isComplete && (
                    <ClinicalInformationSamples
                        samples={
                            pageComponent.patientViewPageStore
                                .clinicalDataGroupedBySample.result!
                        }
                    />
                )}
            </div>

            <h2 className={'divider'}>Timeline Data</h2>

            {pageComponent.patientViewPageStore.clinicalEvents.isComplete && (
                <ClinicalEventsTables
                    clinicalEvents={
                        pageComponent.patientViewPageStore.clinicalEvents.result
                    }
                />
            )}
        </MSKTab>
    );

    tabs.push(
        <MSKTab
            key={4}
            id={PatientViewPageTabs.FilesAndLinks}
            linkText={RESOURCES_TAB_NAME}
            hide={!pageComponent.shouldShowResources}
        >
            <div>
                <ResourcesTab
                    store={pageComponent.patientViewPageStore}
                    sampleManager={
                        pageComponent.patientViewPageStore.sampleManager.result!
                    }
                    openResource={pageComponent.openResource}
                />
            </div>
        </MSKTab>
    );

    tabs.push(
        <MSKTab
            key={3}
            id={PatientViewPageTabs.PathologyReport}
            linkText="Pathology Report"
            hide={!pageComponent.shouldShowPathologyReport}
        >
            <div>
                <PathologyReport
                    iframeHeight={WindowStore.size.height - 220}
                    pdfs={
                        pageComponent.patientViewPageStore.pathologyReport
                            .result
                    }
                />
            </div>
        </MSKTab>
    );

    tabs.push(
        <MSKTab
            key={5}
            id={PatientViewPageTabs.TissueImage}
            linkText="Tissue Image"
            hide={pageComponent.hideTissueImageTab}
        >
            <div>
                <IFrameLoader
                    height={WindowStore.size.height - 220}
                    url={getDigitalSlideArchiveIFrameUrl(
                        pageComponent.patientViewPageStore.patientId
                    )}
                />
            </div>
        </MSKTab>
    );

    pageComponent.showWholeSlideViewerTab &&
        pageComponent.wholeSlideViewerUrl.result &&
        tabs.push(
            <MSKTab
                key={6}
                id={PatientViewPageTabs.MSKTissueImage}
                linkText="Tissue Image"
                unmountOnHide={false}
            >
                <div>
                    <IFrameLoader
                        height={WindowStore.size.height - 220}
                        url={pageComponent.wholeSlideViewerUrl.result!}
                    />
                </div>
            </MSKTab>
        );

    pageComponent.shouldShowTrialMatch &&
        tabs.push(
            <MSKTab
                key={7}
                id={PatientViewPageTabs.TrialMatchTab}
                linkText="Matched Trials"
            >
                <TrialMatchTable
                    sampleManager={sampleManager}
                    detailedTrialMatches={
                        pageComponent.patientViewPageStore.detailedTrialMatches
                            .result
                    }
                    containerWidth={WindowStore.size.width - 20}
                />
            </MSKTab>
        );

        /*pageComponent.studyViewPageStore.getDataForClinicalDataTab.isComplete && pageComponent.patientViewPageStore.mutationData.isComplete&& pageComponent.patientViewPageStore.clinicalDataPatient.isComplete && 
        tabs.push(
                <MSKTab key={45} id={PatientViewPageTabs.PatientSimilarity} linkText="similar Patients">
                    { (
                       <div>  Heleqq3r3lo World {pageComponent.patientViewPageStore.mutationData.result[2].gene.hugoGeneSymbol + pageComponent.patientViewPageStore.mutationHugoGeneSymbols[2]+ pageComponent.patientViewPageStore.mutationData.result[1].proteinChange } 
                              Hello World  <br></br>
                            {pageComponent.studyViewPageStore.getDataForClinicalDataTab.result[1].sampleId}  <br></br>
                            {pageComponent.studyViewPageStore.getDataForClinicalDataTab.result[1].patientId}  <br></br>
                            {pageComponent.studyViewPageStore.getDataForClinicalDataTab.result[1].studyId}  <br></br>
                            {pageComponent.studyViewPageStore.studyIds[1]}  <br></br>
                            {pageComponent.studyViewPageStore.selectedPatients.length} <br></br> 
                            Hello World
                       </div>
                       
                    )}
                    <div> <PatientTable studyViewPageStore={pageComponent.studyViewPageStore} patientViewPageStore={pageComponent.patientViewPageStore} /> </div>
                    
        
                </MSKTab>
        ); */

        pageComponent.patientViewPageStore.mutationData.isComplete&& 
        tabs.push(
                <MSKTab key={45} id={PatientViewPageTabs.PatientSimilarity} linkText="similar Patients">
                    { (
                       <div>  
                         <OverviewTable/>
                       </div>
                       
                    )}
                 
                    
        
                </MSKTab>
        ); 

        pageComponent.patientViewPageStore.mutationData.isComplete&& 
        tabs.push(
                <MSKTab key={46} id={PatientViewPageTabs.PatientComparison} linkText="Patient comparison">
                    { (
                       <div>  <SharedMutationsTable/>
                       </div>
                       
                    )}

                    
        
                </MSKTab>
        );
    pageComponent.shouldShowMtbTab &&
        pageComponent.patientViewPageStore.mutationData.isComplete &&
        pageComponent.patientViewPageStore.discreteCNAData.isComplete &&
        (pageComponent.patientViewPageStore.oncoKbData.isComplete ||
            pageComponent.patientViewPageStore.oncoKbData.isError) &&
        (pageComponent.patientViewPageStore.mtbs.isComplete ||
            pageComponent.patientViewPageStore.mtbs.isError) &&
        (pageComponent.patientViewPageStore.cnaOncoKbData.isComplete ||
            pageComponent.patientViewPageStore.cnaOncoKbData.isError) &&
        tabs.push(
            <MSKTab
                key={42}
                id={PatientViewPageTabs.Mtb}
                linkText="MTB"
                unmountOnHide={false}
            >
                <MtbTable
                    patientId={pageComponent.patientViewPageStore.patientId}
                    mutations={
                        pageComponent.patientViewPageStore.mutationData.result
                    }
                    indexedVariantAnnotations={
                        pageComponent.patientViewPageStore
                            .indexedVariantAnnotations.result
                    }
                    indexedMyVariantInfoAnnotations={
                        pageComponent.patientViewPageStore
                            .indexedMyVariantInfoAnnotations.result
                    }
                    cna={
                        pageComponent.patientViewPageStore.discreteCNAData
                            .result
                    }
                    clinicalData={pageComponent.patientViewPageStore.clinicalDataPatient.result.concat(
                        pageComponent.patientViewPageStore
                            .clinicalDataForSamples.result
                    )}
                    mutationSignatureData={
                        pageComponent.patientViewPageStore
                            .mutationalSignatureDataGroupByVersion.result
                    }
                    sampleManager={sampleManager}
                    oncoKbAvailable={
                        getServerConfig().show_oncokb &&
                        !pageComponent.patientViewPageStore.cnaOncoKbData
                            .isError &&
                        !pageComponent.patientViewPageStore.oncoKbData.isError
                    }
                    mtbs={pageComponent.patientViewPageStore.mtbs.result}
                    deletions={pageComponent.patientViewPageStore.deletions}
                    containerWidth={WindowStore.size.width - 20}
                    onDeleteData={pageComponent.patientViewPageStore.deleteMtbs}
                    onSaveData={pageComponent.patientViewPageStore.updateMtbs}
                    mtbUrl={pageComponent.patientViewPageStore.getMtbJsonStoreUrl(
                        ''
                    )}
                    checkPermission={
                        pageComponent.patientViewPageStore.checkPermission
                    }
                    oncoKbData={pageComponent.patientViewPageStore.oncoKbData}
                    cnaOncoKbData={
                        pageComponent.patientViewPageStore.cnaOncoKbData
                    }
                    pubMedCache={pageComponent.patientViewPageStore.pubMedCache}
                    otherMtbs={
                        pageComponent.patientViewPageStore
                            .localTherapyRecommendations.result
                    }
                    clinicalTrialClipboard={
                        pageComponent.patientViewPageStore
                            .clinicalTrialClipboard
                    }
                />
            </MSKTab>
        );

    pageComponent.shouldShowFollowUpTab &&
        pageComponent.patientViewPageStore.mutationData.isComplete &&
        pageComponent.patientViewPageStore.followUps.isComplete &&
        pageComponent.patientViewPageStore.discreteCNAData.isComplete &&
        (pageComponent.patientViewPageStore.oncoKbData.isComplete ||
            pageComponent.patientViewPageStore.oncoKbData.isError) &&
        (pageComponent.patientViewPageStore.mtbs.isComplete ||
            pageComponent.patientViewPageStore.mtbs.isError) &&
        (pageComponent.patientViewPageStore.cnaOncoKbData.isComplete ||
            pageComponent.patientViewPageStore.cnaOncoKbData.isError) &&
        tabs.push(
            <MSKTab
                key={44}
                id={PatientViewPageTabs.FollowUp}
                linkText="Follow-up"
                unmountOnHide={false}
            >
                <FollowUpTable
                    patientId={pageComponent.patientViewPageStore.patientId}
                    mutations={
                        pageComponent.patientViewPageStore.mutationData.result
                    }
                    indexedVariantAnnotations={
                        pageComponent.patientViewPageStore
                            .indexedVariantAnnotations.result
                    }
                    indexedMyVariantInfoAnnotations={
                        pageComponent.patientViewPageStore
                            .indexedMyVariantInfoAnnotations.result
                    }
                    mutationSignatureData={
                        pageComponent.patientViewPageStore
                            .mutationalSignatureDataGroupByVersion.result
                    }
                    cna={
                        pageComponent.patientViewPageStore.discreteCNAData
                            .result
                    }
                    clinicalData={pageComponent.patientViewPageStore.clinicalDataPatient.result.concat(
                        pageComponent.patientViewPageStore
                            .clinicalDataForSamples.result
                    )}
                    sampleManager={sampleManager}
                    checkPermission={
                        pageComponent.patientViewPageStore.checkPermission
                    }
                    mtbUrl={pageComponent.patientViewPageStore.getMtbJsonStoreUrl(
                        ''
                    )}
                    oncoKbAvailable={
                        getServerConfig().show_oncokb &&
                        !pageComponent.patientViewPageStore.cnaOncoKbData
                            .isError &&
                        !pageComponent.patientViewPageStore.oncoKbData.isError
                    }
                    mtbs={pageComponent.patientViewPageStore.mtbs.result}
                    deletions={pageComponent.patientViewPageStore.deletions}
                    containerWidth={WindowStore.size.width - 20}
                    onDeleteData={
                        pageComponent.patientViewPageStore.deleteFollowUps
                    }
                    onSaveData={
                        pageComponent.patientViewPageStore.updateFollowUps
                    }
                    oncoKbData={pageComponent.patientViewPageStore.oncoKbData}
                    cnaOncoKbData={
                        pageComponent.patientViewPageStore.cnaOncoKbData
                    }
                    pubMedCache={pageComponent.patientViewPageStore.pubMedCache}
                    followUps={
                        pageComponent.patientViewPageStore.followUps.result
                    }
                />
            </MSKTab>
        );

    pageComponent.patientViewPageStore.hasMutationalSignatureData.result &&
        pageComponent.patientViewPageStore.initialMutationalSignatureVersion
            .isComplete &&
        tabs.push(
            <MSKTab
                key={8}
                id="mutationalSignatures"
                linkText="Mutational Signatures"
                hide={
                    pageComponent.patientViewPageStore
                        .mutationalSignatureMolecularProfiles.isPending ||
                    pageComponent.patientViewPageStore
                        .initialMutationalSignatureVersion.isPending ||
                    _.isEmpty(
                        pageComponent.patientViewPageStore
                            .mutationalSignatureDataGroupByVersion.result
                    )
                }
            >
                <MutationalSignaturesContainer
                    data={
                        pageComponent.patientViewPageStore
                            .mutationalSignatureDataGroupByVersion.result
                    }
                    profiles={
                        pageComponent.patientViewPageStore
                            .mutationalSignatureMolecularProfiles.result
                    }
                    onVersionChange={
                        pageComponent.onMutationalSignatureVersionChange
                    }
                    version={
                        pageComponent.patientViewPageStore
                            .selectedMutationalSignatureVersion
                    }
                    dataCount={
                        pageComponent.patientViewPageStore
                            .mutationalSignatureCountDataGroupedByVersion.result
                    }
                    sample={
                        pageComponent.patientViewPageStore
                            .selectedSampleMutationalSignatureData
                    }
                    samples={
                        pageComponent.patientViewPageStore
                            .samplesWithCountDataAvailable
                    }
                    samplesNotProfiled={
                        pageComponent.patientViewPageStore
                            .samplesNotProfiledForMutationalSignatures
                    }
                    onSampleChange={pageComponent.onSampleIdChange}
                />
            </MSKTab>
        );

    tabs.push(
        <MSKTab
            key={43}
            id={PatientViewPageTabs.ClinicalTrialsGov}
            linkText="ClinicalTrialsGov"
            unmountOnHide={false}
        >
            <ClinicalTrialMatchTable
                store={pageComponent.patientViewPageStore}
                clinicalTrialMatches={
                    pageComponent.patientViewPageStore.clinicalTrialMatches
                        .result
                }
                mtbTabAvailable={pageComponent.shouldShowMtbTab}
            />
        </MSKTab>
    );

    pageComponent.resourceTabs.component &&
        /* @ts-ignore */
        tabs.push(...pageComponent.resourceTabs.component);

    tabs.push(...buildCustomTabs(pageComponent.customTabs));

    // {getServerConfig().custom_tabs &&
    //     getServerConfig()
    //         .custom_tabs.filter(
    //             (tab: any) =>
    //                 tab.location === 'PATIENT_PAGE'
    //         )
    //         .map((tab: any, i: number) => {
    //             return (
    //                 <MSKTab
    //                     key={getPatientViewResourceTabId(
    //                         'customTab' + i
    //                     )}
    //                     id={getPatientViewResourceTabId(
    //                         'customTab' + i
    //                     )}
    //                     unmountOnHide={
    //                         tab.unmountOnHide ===
    //                         true
    //                     }
    //                     onTabDidMount={div => {
    //                         this.customTabMountCallback(
    //                             div,
    //                             tab
    //                         );
    //                     }}
    //                     linkText={tab.title}
    //                 ></MSKTab>
    //             );
    //         })}

    return tabs;
}
